# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_bigquery_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_bigquery_pb2 as gcp_dot_gcp__bigquery__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$gcp/gcp_google_bigquery_bundle.proto\x12&oak9.tython.gcp.google_bigquery_bundle\x1a\x13shared/shared.proto\x1a\x16gcp/gcp_bigquery.proto\"\xbb\x06\n\x0eGoogleBigquery\x12\x43\n\x10\x62igquery_dataset\x18\x01 \x01(\x0b\x32).oak9.tython.gcp.bigquery.BigqueryDataset\x12P\n\x17\x62igquery_dataset_access\x18\x02 \x03(\x0b\x32/.oak9.tython.gcp.bigquery.BigqueryDatasetAccess\x12Y\n\x1c\x62igquery_dataset_iam_binding\x18\x03 \x03(\x0b\x32\x33.oak9.tython.gcp.bigquery.BigqueryDatasetIamBinding\x12W\n\x1b\x62igquery_dataset_iam_member\x18\x04 \x03(\x0b\x32\x32.oak9.tython.gcp.bigquery.BigqueryDatasetIamMember\x12W\n\x1b\x62igquery_dataset_iam_policy\x18\x05 \x03(\x0b\x32\x32.oak9.tython.gcp.bigquery.BigqueryDatasetIamPolicy\x12\x43\n\x10\x62igquery_routine\x18\x06 \x03(\x0b\x32).oak9.tython.gcp.bigquery.BigqueryRoutine\x12?\n\x0e\x62igquery_table\x18\x07 \x03(\x0b\x32\'.oak9.tython.gcp.bigquery.BigqueryTable\x12U\n\x1a\x62igquery_table_iam_binding\x18\x08 \x03(\x0b\x32\x31.oak9.tython.gcp.bigquery.BigqueryTableIamBinding\x12S\n\x19\x62igquery_table_iam_member\x18\t \x03(\x0b\x32\x30.oak9.tython.gcp.bigquery.BigqueryTableIamMember\x12S\n\x19\x62igquery_table_iam_policy\x18\n \x03(\x0b\x32\x30.oak9.tython.gcp.bigquery.BigqueryTableIamPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_bigquery_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLEBIGQUERY._serialized_start=126
  _GOOGLEBIGQUERY._serialized_end=953
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import gcp.gcp_dataflow_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleDataflow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATAFLOW_JOB_FIELD_NUMBER: builtins.int
    @property
    def dataflow_job(self) -> gcp.gcp_dataflow_pb2.DataflowJob: ...
    def __init__(
        self,
        *,
        dataflow_job: gcp.gcp_dataflow_pb2.DataflowJob | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dataflow_job", b"dataflow_job"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dataflow_job", b"dataflow_job"]) -> None: ...

global___GoogleDataflow = GoogleDataflow



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_bigquery_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleBigquery(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BIGQUERY_DATASET_FIELD_NUMBER: builtins.int
    BIGQUERY_DATASET_ACCESS_FIELD_NUMBER: builtins.int
    BIGQUERY_DATASET_IAM_BINDING_FIELD_NUMBER: builtins.int
    BIGQUERY_DATASET_IAM_MEMBER_FIELD_NUMBER: builtins.int
    BIGQUERY_DATASET_IAM_POLICY_FIELD_NUMBER: builtins.int
    BIGQUERY_ROUTINE_FIELD_NUMBER: builtins.int
    BIGQUERY_TABLE_FIELD_NUMBER: builtins.int
    BIGQUERY_TABLE_IAM_BINDING_FIELD_NUMBER: builtins.int
    BIGQUERY_TABLE_IAM_MEMBER_FIELD_NUMBER: builtins.int
    BIGQUERY_TABLE_IAM_POLICY_FIELD_NUMBER: builtins.int
    @property
    def bigquery_dataset(self) -> gcp.gcp_bigquery_pb2.BigqueryDataset: ...
    @property
    def bigquery_dataset_access(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryDatasetAccess]: ...
    @property
    def bigquery_dataset_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryDatasetIamBinding]: ...
    @property
    def bigquery_dataset_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryDatasetIamMember]: ...
    @property
    def bigquery_dataset_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryDatasetIamPolicy]: ...
    @property
    def bigquery_routine(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryRoutine]: ...
    @property
    def bigquery_table(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryTable]: ...
    @property
    def bigquery_table_iam_binding(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryTableIamBinding]: ...
    @property
    def bigquery_table_iam_member(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryTableIamMember]: ...
    @property
    def bigquery_table_iam_policy(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_bigquery_pb2.BigqueryTableIamPolicy]: ...
    def __init__(
        self,
        *,
        bigquery_dataset: gcp.gcp_bigquery_pb2.BigqueryDataset | None = ...,
        bigquery_dataset_access: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryDatasetAccess] | None = ...,
        bigquery_dataset_iam_binding: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryDatasetIamBinding] | None = ...,
        bigquery_dataset_iam_member: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryDatasetIamMember] | None = ...,
        bigquery_dataset_iam_policy: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryDatasetIamPolicy] | None = ...,
        bigquery_routine: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryRoutine] | None = ...,
        bigquery_table: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryTable] | None = ...,
        bigquery_table_iam_binding: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryTableIamBinding] | None = ...,
        bigquery_table_iam_member: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryTableIamMember] | None = ...,
        bigquery_table_iam_policy: collections.abc.Iterable[gcp.gcp_bigquery_pb2.BigqueryTableIamPolicy] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bigquery_dataset", b"bigquery_dataset"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bigquery_dataset", b"bigquery_dataset", "bigquery_dataset_access", b"bigquery_dataset_access", "bigquery_dataset_iam_binding", b"bigquery_dataset_iam_binding", "bigquery_dataset_iam_member", b"bigquery_dataset_iam_member", "bigquery_dataset_iam_policy", b"bigquery_dataset_iam_policy", "bigquery_routine", b"bigquery_routine", "bigquery_table", b"bigquery_table", "bigquery_table_iam_binding", b"bigquery_table_iam_binding", "bigquery_table_iam_member", b"bigquery_table_iam_member", "bigquery_table_iam_policy", b"bigquery_table_iam_policy"]) -> None: ...

global___GoogleBigquery = GoogleBigquery
